{ config, lib, pkgs, ... }:
{
  # Bootloader.
  boot = {
    loader = {
      systemd-boot = {
        enable = true;
        configurationLimit = 8;
      };
      efi.canTouchEfiVariables = true;
    };
    kernelPackages = pkgs.linuxPackages_latest;
    kernelModules = [
      "i2c-dev"
      "ddcci-backlight"
      "uinput"
      "hid-playstation"
      "amd_pstate=active"
    ];
    extraModulePackages = with config.boot.kernelPackages; [
      ddcci-driver
      # openrazer
    ];
    extraModprobeConfig = ''
      options bluetooth disable_ertm=Y
    '';
    initrd.systemd.enable = true;
    initrd.kernelModules = [
      "nvidia"
      "nvidia_modeset"
      "nvidia_uvm"
      "nvidia_drm"
      "snd-virmidi"
    ];
    kernelParams = [
      "nvidia_drm.fbdev=1"
      "nvidia_drm.modeset=1"
    ];
    supportedFilesystems = [ "nfs" ];
  };
}
